#!/usr/bin/env python3

import re
import sys

# big5 (traditional) or gb2312 (simplified)
encoding = sys.argv[1]

# nested dict of syllables => characters => frequency
syllables = {}

# Unihan_Readings.txt is part of Unihan.zip, see
# http://www.unicode.org/Public/UNIDATA/Unihan.zip
for line in open('Unihan_Readings.txt', encoding='utf8'):
    if line.startswith('#') or line.isspace():
        continue
    cp, field, readings = line.strip().split('\t')
    if field != 'kHanyuPinlu':
        continue
    assert cp.startswith('U+')
    c = chr(int(cp[2:], base=16))
    try:
        c.encode(encoding)
    except UnicodeEncodeError:
        continue
    for r in readings.split():
        syllable, freq = re.match(r'^(\w+)\d\((\d+)\)$', r).groups()
        freq = int(freq)
        if syllable not in syllables:
            syllables[syllable] = {}
        if c not in syllables[syllable]:
            syllables[syllable][c] = freq

for n, syllable in enumerate(sorted(syllables.keys()), 1):
    chars = sorted(syllables[syllable].keys(),
                   key=lambda c: syllables[syllable][c],
                   reverse=True)
    print('%d\t%s\t%s' % (n, syllable, ''.join(chars)))
